( cd usr/share/doc/HTML/da/krecipes ; rm -rf common )
( cd usr/share/doc/HTML/da/krecipes ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/en/krecipes ; rm -rf common )
( cd usr/share/doc/HTML/en/krecipes ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/es/krecipes ; rm -rf common )
( cd usr/share/doc/HTML/es/krecipes ; ln -sf /usr/share/doc/HTML/es/common common )
( cd usr/share/doc/HTML/et/krecipes ; rm -rf common )
( cd usr/share/doc/HTML/et/krecipes ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/pt/krecipes ; rm -rf common )
( cd usr/share/doc/HTML/pt/krecipes ; ln -sf /usr/share/doc/HTML/pt/common common )
( cd usr/share/doc/HTML/sv/krecipes ; rm -rf common )
( cd usr/share/doc/HTML/sv/krecipes ; ln -sf /usr/share/doc/HTML/sv/common common )
